package com.keysight.repository.client;

import java.util.List;

import javax.ws.rs.client.Client;
import javax.ws.rs.client.ClientBuilder;
import javax.ws.rs.client.Entity;
import javax.ws.rs.client.WebTarget;
import javax.ws.rs.core.GenericType;
import javax.ws.rs.core.MediaType;

import com.keysight.repository.model.Credentials;
import com.keysight.repository.model.Dataset;
import com.keysight.repository.model.Measurement;
import com.keysight.repository.model.MeasurementType;
import com.keysight.repository.model.PropertyType;

public class KeysightRepositoryClient {

	private Client client;
	private WebTarget apiRoot;
	
	private KeysightRepositoryClient() {
		
	}
	
	private void initialize(String serverHostname, int port) {
		client = ClientBuilder.newClient().register(new CookieFilter()).register(new ErrorLoggingFilter());
		apiRoot = client.target("http://" + serverHostname + ":" + port + "/api");
	}
	
	public void close() {
		client.close();
		apiRoot = null;
	}
	
	public static KeysightRepositoryClient open(String serverHostname, int port) {
		KeysightRepositoryClient result = new KeysightRepositoryClient();
		result.initialize(serverHostname, port);
		return result;
	}
	
	public void login(Credentials credentials) {
		apiRoot.path("users/current")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.post(Entity.entity(credentials, MediaType.APPLICATION_JSON));
	}
	
	public List<Dataset> getDatasets() {
		return apiRoot.path("datasets")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.get(new GenericType<List<Dataset>>() {});
	}
	
	public Dataset createDataset(Dataset dataset) {
		return apiRoot.path("datasets")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.post(Entity.entity(dataset, MediaType.APPLICATION_JSON), Dataset.class);
	}
	
	public List<MeasurementType> getMeasurementTypesForDataset(int datasetId) {
		return apiRoot.path("datasets").path(String.valueOf(datasetId)).path("measurement-types")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.get(new GenericType<List<MeasurementType>>() {});
	}
	
	public List<MeasurementType> createMeasurementTypes(int datasetId, List<MeasurementType> measurementTypes) {
		return apiRoot.path("datasets").path(String.valueOf(datasetId)).path("measurement-types")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.post(Entity.entity(measurementTypes, MediaType.APPLICATION_JSON), new GenericType<List<MeasurementType>>() {});
	}
	
	public List<PropertyType> getPropertyTypesForDataset(int datasetId) {
		return apiRoot.path("datasets").path(String.valueOf(datasetId)).path("property-types")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.get(new GenericType<List<PropertyType>>() {});
	}
	
	public List<PropertyType> createPropertyTypes(int datasetId, List<PropertyType> propertyTypes) {
		return apiRoot.path("datasets").path(String.valueOf(datasetId)).path("property-types")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.post(Entity.entity(propertyTypes, MediaType.APPLICATION_JSON), new GenericType<List<PropertyType>>() {});
	}
	
	public List<Measurement> getMeasurementsOfType(int datasetId, int measurementTypeId) {
		return apiRoot.path("datasets").path(String.valueOf(datasetId)).path("measurements").path(String.valueOf(measurementTypeId))
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.get(new GenericType<List<Measurement>>() {});
	}
	
	public void createMeasurement(int datasetId, Measurement measurement) {
		int result = apiRoot.path("datasets").path(String.valueOf(datasetId)).path("measurements")
				.request()
				.accept(MediaType.APPLICATION_JSON)
				.post(Entity.entity(measurement, MediaType.APPLICATION_JSON))
				.getStatus();
		if(result >= 300) {
			throw new RuntimeException("Unexpected result creating measurement: " + result);
		}
	}
}
