package com.keysight.repository.model;

/**
 * A dataset maps to a domain model for which you would like to make measurements.  Each dataset
 * can have its own measurement types and property types and could represent very different projects
 * with different types of measurements that are made.
 */
public class Dataset {

	private int id;
	private int measurementCount;
	private String name;
	
	protected Dataset() {
		
	}
	
	/**
	 * Constructs a dataset
	 * @param name The name of the dataset
	 */
	public Dataset(String name) {
		this.name = name;
	}

	/**
	 * Returns the repository id of the dataset.  This is set by the repository server
	 * when the dataset is created.
	 * @return The repository id of the dataset
	 */
	public int getId() {
		return id;
	}
	
	/**
	 * Returns the number of measurements in the dataset
	 * @return the number of measurements in the dataset
	 */
	public int getMeasurementCount() {
		return measurementCount;
	}

	/**
	 * Returns the name of the dataset
	 * @return the name of the dataset
	 */
	public String getName() {
		return name;
	}
	
}
