package com.keysight.repository.model;

import java.util.List;

/**
 * This represents a measurement that will be or has been stored in the repository.  Each measurement
 * has a measurement type, a value, and a list of propertie values that were set when the measurement
 * was made.
 */
public class Measurement {

	private int id;
	private double value;
	private int measurementTypeId;
	private List<Property> properties;
	
	protected Measurement() {
		
	}
	
	/**
	 * Constructs a measurement
	 * @param measurementTypeId The type of measurement
	 * @param value The value of the measurement
	 * @param properties The properties present when the measurement was made
	 */
	public Measurement(int measurementTypeId, double value, List<Property> properties) {
		this.measurementTypeId = measurementTypeId;
		this.value = value;
		this.properties = properties;
	}
	
	/**
	 * Returns the repository id of the measurement.  This will be set by the repository
	 * server when the measurement is created.
	 * @return The repository id of the measurement
	 */
	public int getId() {
		return id;
	}
	
	/**
	 * Returns the value of the measurement
	 * @return The value of the measurement
	 */
	public double getValue() {
		return value;
	}
	
	/**
	 * Returns the measurement type id
	 * @return the measurement type id
	 */
	public int getMeasurementTypeId() {
		return measurementTypeId;
	}
	
	/**
	 * Returns the properties present when the measurement was made
	 * @return the properties present when the measurement was made
	 */
	public List<Property> getProperties() {
		return properties;
	}
	
}
