package com.keysight.repository.model.builder;

import java.util.ArrayList;
import java.util.List;

import com.keysight.repository.model.Measurement;
import com.keysight.repository.model.MeasurementType;
import com.keysight.repository.model.Property;
import com.keysight.repository.model.PropertyType;

public class MeasurementBuilder {

	private int measurementTypeId;
	private double value;
	private List<Property> properties = new ArrayList<Property>();
	
	private MeasurementBuilder(int measurementTypeId, double value) {
		this.measurementTypeId = measurementTypeId;
		this.value = value;
	}
	
	public static MeasurementBuilder newInstance(MeasurementType measurementType, double value) {
		return new MeasurementBuilder(measurementType.getId(), value);
	}
	
	public static MeasurementBuilder newInstance(int measurementTypeId, double value) {
		return new MeasurementBuilder(measurementTypeId, value);
	}
	
	public MeasurementBuilder addProperty(PropertyType propertyType, String value) {
		return addProperty(propertyType.getId(), value);
	}
	
	public MeasurementBuilder addProperty(int propertyTypeId, String value) {
		properties.add(new Property(propertyTypeId, value));
		return this;
	}
	
	public Measurement build() {
		return new Measurement(measurementTypeId, value, properties);
	}
	
}
